@@ -18,7 +18,7 @@ console._force_terminal = True
 import envo.e2e
 
 from envo import e2e
-from envo.logging import logger
+from envo.logs import logger
 from envo.devops import *
 from envo.env import *
 from envo.plugins import *
